==> haskell-file-embed-0.0.11.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 file-embed
version:              0.0.11.2
visibility:           public
id:                   file-embed-0.0.11.2-76jJzrpjGcdDpzOtgwH8dS
key:                  file-embed-0.0.11.2-76jJzrpjGcdDpzOtgwH8dS
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/file-embed
synopsis:             Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.

category:             Data
abi:                  90f09e665510489dd595d176aab8d1c7
exposed:              True
exposed-modules:      Data.FileEmbed
import-dirs:          /usr/lib/ghc-8.8.3/site-local/file-embed-0.0.11.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/file-embed-0.0.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/file-embed-0.0.11.2
hs-libraries:         HSfile-embed-0.0.11.2-76jJzrpjGcdDpzOtgwH8dS
depends:
    base-4.13.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html:         /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-file-embed-0.0.11.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 file-embed
version:              0.0.11.2
visibility:           public
id:                   file-embed-0.0.11.2-FLtarAa7jT5B4p21LSGJrt
key:                  file-embed-0.0.11.2-FLtarAa7jT5B4p21LSGJrt
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             https://github.com/snoyberg/file-embed
synopsis:             Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.

category:             Data
abi:                  fb13b7bdc560d2aab15f41c2dfa2fcc9
exposed:              True
exposed-modules:      Data.FileEmbed
import-dirs:          /usr/lib/ghc-8.10.1/site-local/file-embed-0.0.11.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/file-embed-0.0.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/file-embed-0.0.11.2
hs-libraries:         HSfile-embed-0.0.11.2-FLtarAa7jT5B4p21LSGJrt
depends:
    base-4.14.0.0 bytestring-0.10.10.0 directory-1.3.6.0
    filepath-1.4.2.1 template-haskell-2.16.0.0

haddock-interfaces:   /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html:         /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
